StreamDataSource<T> class

A GridDataSource backed by a Stream of lists.

Constructors

StreamDataSource({required Stream<List<T>> streamBuilder(GridQuery query)})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamBuilder → Stream<List<T>> Function(GridQuery query)
final

Methods

delete(dynamic id) → Future<bool>
inherited
fetch(GridQuery query) → Future<GridPage<T>>
insert(T item) → Future<T?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(T item) → Future<T?>
inherited
watch(GridQuery query) → Stream<List<T>>?

Operators

operator ==(Object other) → bool
The equality operator.
inherited